# ¿Puede pensar la inteligencia artificial?

Este texto no aporta nada significativo al campo de la inteligencia artificial 
(IA) ni tampoco al campo de estudio con el que se piensa contrastar; a saber, 
la historiografía regional colimense o, en un sentido más amplio, a la historia 
de la conquista de América. El objetivo de este escrito es «ensayar»: «jugar» 
con un posible nexo entre disciplinas tan dispares para poder revisitar un 
problema presente en la teoría de la IA que se sintetiza con el título de este 
documento.

## La inteligencia artificial y el problema del «pensar»

Dentro de la teoría de la IA se da por sentado la división del campo de estudio 
en dos grandes ramas:

1. La IA «débil» o «estrecha» que consiste en diseñar un sistema para que
   resuelva una tarea en específico. Ejemplos tenemos la IA que puede jugar
   ajedrez o go, o que es capaz de manejar un automóvil o mantener una
   conversación con una persona. Se le llama «estrecha» porque más allá de esa
   tarea específica, que quizá puede realizarla mejor que una persona,
   no puede hacer nada más. Incluso cuando dentro de esa misma tarea aparece
   una nueva variable que no había sido completada, este sistema tiende a 
   fallar; p. ej. la modificación del tablero de ajedrez o de go a una forma
   hexagonal. En este sentido es «débil» ya que su adaptabilidad requiere de una 
   modificación de su código fuente, a diferencia de las personas, que en mayor 
   o menor medida pueden llevar a cabo la misma función tomando en cuenta el 
   nuevo contexto.

2. La IA «fuerte» o «general» que consiste en la creación de un sistema que al
   menos tenga la capacidad de realizar tareas de diversa índole. Esta clase de 
   IA es inexistente en la actualidad por los retos que plantea. Sin embargo, 
   en teoría se visualiza con la capacidad de equiparar o superar las 
   capacidades «cognitivas» humanas. Ejemplos de esta clase de IA se encuentran
   en la ciencia ficción como HAL 9000 o la Matrix. Es «general» porque no está 
   diseñada para cumpliar una tarea en específico. Y se le denomina «fuerte» ya 
   que su índice de adaptabilidad a nuevos contextos se perfila de manera 
   equitativa a las capacidades humanas.

En uno u otro caso existe esa división de la IA entre la «práctica», la 
«acción», y lo que se encuentra en estado «teórico», en un «discurso». La IA 
«fuerte» se constituye como un límite, un ideal, que da dirección y norma el 
quehacer actual de quienes desarrollan la IA «débil». O viéndolo de otra manera, 
el campo de la IA no nace ni se entendería plenamente sin el constante optimismo 
presente en la disciplina de aproximarse a la ficción y de cómo su continuo 
fracaso no se percibe como un paso regresivo, sino como un aprendizaje que va 
*hacia adelante* en la consecución de dicho ideal.

Pero prefiero otra división cuando se trata del problema sobre si la IA 
«piensa», que a lo largo de este texto intentaré indicar su pertinencia:

1. La IA que pretende «emular» el modo de pensar humano.
2. La IA que se concibe como la «exploración» de un tipo de pensar no-humano.

¿Es posible «pensar» en términos no humanos? Se trata de una pregunta que ni se
asiente ni se niega porque aún no existen los datos suficientes como para
aventurarnos a indicar que se conoce todo el transfondo de lo que involucra
el pensamiento. Las neurociencias y la filosofía de la mente, aunque están
siempre presente en el campo de la IA, aún no dan los elementos suficientes para
refutar o comprobar esta hipótesis.

No obstante, ya sea una «emulación» o una «exploración», de un modo usual se
tiende a hablar de «pensar» y de «conciencia» de la IA y de cómo esta 
«singularidad» puede tener tal importancia histórica como el surgimiento de
la filosofía a partir de diversas tradiciones, principalmente asiáticas o
africanas, la llegada del cristianismo a Occidente, el Renacimiento o el
surgimiento del pensamiento moderno. La pregunta es: si aún no existen datos
suficientes sobre lo que es «pensar» que nos permita tener una aproximación 
clara sobre la «emulación» o «exploración» de nuevas formas de pensar, ¿por qué 
sin ningún reparo se habla de «pensar» y de «conciencia» de la IA?

Una respuesta podría ser que al no existir todavía conceptos que se adecúen a
lo que se está realizando en la IA, se recurre a los términos de «pensar»,
«conciencia», «entendimiento» o «aprendizaje» de manera equívoca, como metáfora 
o analogía para que sea más fácil el entendimiento del objeto de estudio de
esta disciplina. Suena convincente pero hay un problema: si se recurre a un
significado figurativo de los vocablos debido a que no hay palabra que pueda
describir a esa cosa llamada IA, ¿por qué no mejor se usan las nociones de
«ejecutar», «procesar», «relacionar» o «guardar», es decir, términos un tanto
más «maquinales»?

Ojo: en gran parte de las profundidades de la teoría e ingeniería de la IA
efectivamente no se usan los términos de «pensar», «conciencia», etc. Sin
embargo, es extraño que de modo coloquial las personas involucradas en esta
disciplina se expresen de esta manera, ya que más allá de jugar con la
flexibilidad de los conceptos, es también una muestra de cómo se perciben a sí
mismos y a su campo de estudio. ¿Acaso no sería más entendible para el público
general que la IA es una computadora muy avanzada que procesa información en
lugar de hablar de algo aún más perplejo como lo es la «conciencia» y el
«pensamiento»? Quizá es porque de manera efectiva la IA es o será algo más que 
una supercomputadora recursiva, pero tal vez no es sino cómo el personal 
involucrado *se ve a sí mismo creando algo que no es solo una «máquina»*.

La insistencia parece necia, «¿Qué importa si en la divulgación o entre pláticas
del día a día se hable de “pensamiento”, “conciencia”, “entendimiento” o
“aprendizaje”?, ¿qué más da si la IA “piensa” o no? Carece de sentido, lo
*esencial* es que se están creando sistemas que tienen una mejor capacidad de
predicción y de creación de vínculos que los humanos, incluso al punto que
es tan grato como alarmante». Cuando el «pensar» y el «ser conciente» se 
descorporaliza, se «abstrae», poco o nada puede alarmar la extrapolación de 
términos cuya base fenoménica son las funciones biológicas de un cuerpo.

La abstracción se dio desde muy temprano en la historia de la filosofía
occidental. Platón y su mundo de las ideas no solo creó una dicotomía entre
el «alma» y el «cuerpo», también fundó la base para entender el proceso del
pensar, y de paso del filosofar, como una labor que poco o nada se parece a otro
tipo de quehacer, como puede ser la creación de una escultura o el cultivo
de un campo. De Aristóteles a la escolástica el proceso de «pensar» se fue
asociando cada vez un poco más a un Ser o un Dios, en forma de metafísicas,
teologías o pruebas ontológicas orientadas a la perfectibilidad del ser.

Con Descartes el acto de pensar empieza a secularizarse al fundar a Dios como 
sustancia distinta y de base para la *res cogitans* y la *res extensa*. El 
proceso es interesante, ya que la desvinculación es por lo menos triple: 
1) separación del *cogito* de Dios, 2) distanciamiento entre la *res cogitans* 
y la *res extensa*, y 3) la plena ausencia de la carne en el *cogito*. Si
con Aristóteles y la escolástica se trataba de crear un vínculo entre lo
terrenal y lo divino a través del raciocinio o la fe, que en uno u otro caso
implican la necesidad de pensar, en Descartes ni hay nexo concreto entre
Dios y el hombre ni relación entre el pensar y la función biológica que
precisa el cerebro para funcionar.

El idealismo alemán y el psicologismo, aunque vertientes muy dispares, en
este sentido no harán sino abstraer aún más el pensar de su base biológica,
hasta un límite que horrorizó a Husserl. La vuelta a las cosas mismas y el
carácter de la intencionalidad de la conciencia de la fenomenología filosófica
se perfiló como un gran candidato para la encarnación de vuelta del pensar.
Pero el ánimo duró poco y de la fenomenología Husserl retornó al carácter
«eidético» del pensar. Y aunque el quehacer filosófico «continental» a partir
de Husserl empezó a revincular el pensar con el «cuerpo» y la existencia en
su organicidad y sociabilidad, el surgimiento de la filosofía «analítica» 
decidió orientarse a la lógica, el lenguaje, las ciencias «duras» y 
posteriormente a la mente: la raíz y fundamento filosófico de la teoría de 
la IA.

Este cuento estercolero tiene la finalidad de hacer notar que el vínculo entre
el «pensar» y la «conciencia» con las funciones biológicas de un «cuerpo» es
una condición necesaria para que se pueda hablar de una y otra cosa, donde su
«inesencialidad» es más un constructo que un «hecho». O en otros términos, el 
ser que piensa y que es consciente también es un ser vivo; queya muerto no 
existe seguridad si sigue pensando o siendo consciente. (Una excepción es Dios, 
que es omnisciente sin que sean aplicables las categorías de vida-muerte, pero 
dejémoslo como una historia aparte). Pero no solo eso, lo que entendemos por 
«pensar» está asociado de una u otra forma a una estructura orgánica cerebral 
desde un sentido abierto donde entran los animales humanos y no-humanos, pasando 
al intermedio por el cual solo los homínidos forman parte del club, hasta el 
completo cierre en nuestra especie. 

La reducción es tal que la cualidad de pensar y de ser conciente solo es
aplicable a ciertos seres vivos con una estructura cerebral. ¿Cómo pues es que
no hay problema con aplicar estas categorías a entidades que ni tienen órgano
cerebral ni están vivos? ¡Vaya desgracia para los defensores de la dignidad
animal, que durante milenios han luchado por los derechos de los que no pueden
hablar, mientras que para los creadores de chips y código sin ningún problema
se admite la entrada de sus creaciones al club!

Más allá de una búsqueda de mantener al «pensar» y a la «conciencia» en sus
límites biológicos, de denunciar una «violencia teórica» o de argumentar que, 
en efecto, la IA no piensa, quizá un recorrido en otro campo ayude a mostrar 
otra cara de este problema…

## El «decubrimiento», «invención», «encuentro», «desencuentro» y «choque» de América

Cuando Colón arribó al Caribe ignoró que estaba tocando pie en un «nuevo»
continente. Pese a las sospechas que lo fastidiarían el resto de sus días,
el «descubridor» de América siempre pensó que lo que había «descubierto» era
una nueva ruta a las Indias. Vaya carácter enigmático el de este fenómeno 
ya que a partir del desconocimiento paulatinamente se forjaría una idea de lo 
que se conocería como Nuevo Mundo y, más tarde, América.

Este proceso que parte del desconocimiento hasta la confrontación, no solo en
el plano bélico sino también en el discurso, es lo que de cierta manera
permite indicar que fueron los españoles, primero los aventureros y luego los
conquistadores y evangelizadores, los «descubridores» de América. Contactos 
entre este continente y el resto ya habían existido: lo que conocemos por 
América no estaba del todo aislado, simplemente estaba afuera, era el límite de 
las cosmovisiones de las culturas europeas, asiáticas, africanas u oceánicas. 
Así como en la antigua Grecia todo aquello fuera de la influencia helénica era 
considerado «bárbaro», así también América no había sido incorporando al 
horizonte de sentido de las culturas al otro lado del océano. Es más, América 
no era ni «bárbara», ya que esto implica una incorporación negativa, era por lo 
menos un mito, aunque para la mayoría una «nada».

Las exploraciones, conquistas, colonización y evangelización españolas serían
el punto de arrastre que anexionarían este continente en el marco de la
cultura occidental. Más que el europeo haya dotado de «ser» a América, le
implantó un orden de las cosas en torno a algo tan desconocido y euroasiático
como lo es el concepto de «ser». El verbo «dotar» no es un simple «dar» sino
un «otorgar algo que se necesita», ¿cómo pues se podría dotar de «ser» a
este continente si la noción de «ser» (ojo, no de «lo que es») ni existía y
durante mucho tiempo tampoco fue menester?

«Nuevo Mundo», difícilmente será un término que vuelva a resurgir en nuestra
historia debido al avance de la técnica. En el siglo XVI la capacidad de
observación, entendida como una visión que no solo contempla, sino que también
absorbe lo que tiene en su mirada, estaba en reciente expansión. Mientras tanto,
en la actualidad esta capacidad ya ni siquiera se mide en kilómetros, sino en
años luz. Es tal la dilatación de nuestra capacidad de observación que ya hemos 
incorporado en nuestro horizonte de sentido lugares en el universo que tal vez
nunca alcanzaremos, destruyendo nuestro lugar privilegiado en el cosmos así como
la misma idea de «cosmos» e imposibilitando esa completa paralización que supone
el tocar pie en una tierra que ni se sabe dónde estaba ni «qué era».

Este es el sentido primogenio de un de repente, sin anticipación alguna, toparse
con una entidad geográfica que se suponía «no estaba ahí». No solo lo digo
por el desconocimiento y asombro que tuvieron los europeos al venir a América,
sino también del desasosiego y shock que los americanos palparon al ver y
tener noticia de la existencia de esas otras tierras. Aunque el término de
«Nuevo Mundo» históricamente se haya aplicado a la noción occidental sobre
América, este concepto bien es aplicable a la sensasión que los americanos
sintieron respecto de Europa. Ni América tenía que estar ahí, ni el resto de 
los continentes se suponía que yacían ahí. El grado de ignoracia por ambas 
partes fue tal, que por ello en nuestros días difícilmente y sin previo aviso 
una masa geográfica se aparecerá ante nuestra mirada expectante, y más si se 
cae en cuenta que esta aparición *ex nihilo* no fue una llana masa inerte, 
sino llena de «vida» con un grado de familiaridad enorme.

La aparición de «nueva vida», más específicamente de «vida semejante» es lo
que empezó un proceso de asimilación que no fue políticamente neutro ni del
todo propio de cada uno de los individuos, americanos o españoles. ¿De qué 
manera traer a sí algo tan desconocido pero al mismo tiempo tan similar? ¿Cómo, 
pues, cada cultura iba a incorporar a su horizonte cultural una «nada» que casi 
de la noche a la mañana se develó como un «ser como otro»? El «ensueño de la 
imaginación», como gusta llamarse Romero de Solís, fue precisamente el vínculo 
dentro de esta crisis de identidad.

Cuando algo tan «irreal» cae sin previsión en el mero centro de una «realidad»
considerada consumada, es la ida a sus límites, el retrotraerse, lo que facilita 
su digestión a prisa, con desvelo y a contrapelo. Los americanos no necesitaban 
de los españoles para darle cumplimiento a su realidad: la idea de la espera 
del regreso de Quetzalcóatl no era una opinión compartida por muchos. Ni los
españoles precisaban de América para terminar de pulir su realidad: querían
nuevas rutas de mercado, la Corona anhelaba la legitimación de su poder ante
una Europa perspicaz con sus acciones. Pero pese a esta autosuficiencia, 
América se convirtió en el umbral que trajo a España a su edad de oro, en 
sentido figurado y literal, y lo que convirtió a los españoles en entes
divinizados.

Este desenvolvimiento de los hechos no me parece que haya sido ingenuidad por 
parte de los americanos o suerte de los españoles. En los límites de lo real
aconteció una incorporación que permitió un ver cara a cara el otro a partir
de la ficción y el mito. Para los españoles América fue la expresión concreta
de sus novelas caballerescas. Mientras que para los americanos fue la
condensación de mitos en ese modo tan suyo de presentarse: como creencia pero 
recelo al mismo tiempo.

Un aspecto interesante es que la asimilación española no fue a través de la
incorporación de personas a su mundo, sino la anexión de tierras y riquezas.
En el universo discursivo de las novelas caballerescas de lo que se hablaba
era de doncellas, enemigos destruidos de manera heróica, fama, gloria y 
riquezas. Nada distinto a los planes generales de Hernán Cortés, a su estricto 
cuidado en conocer toda la geografía de Mesoamérica o en mandar a explorar por 
la noticia de que en Colima, específicamente en Cihuatlán (ahora parte de 
Jalisco) había un lugar con mujeres hermosas, las Amazonas, y con muchas perlas. 
Nada tampoco opuesto a Nuño de Guzmán y la exterminación sin peso de conciencia 
de los americanos, su lucha heróica por el occidente mesoamericano, ahora Nueva
Galicia. Ni extraña el hecho que ante el desobedimiento de sus huestes y el 
primer enfrentamiento con los nativos de Colima, al parecer en Tecomán o 
Armería, Hernán Cortés mandará a unos de sus generales de mayor confianza, 
Gonzalo de Sandoval, a que inmediatamente fuese a «pacificar» estas tierras, 
independientemente de que se encontrara en el Pánuco: no solo era una 
desestabilización política por abrir nuevos frentes cuando en otros la victoria 
aún no estaba asegurada, también implicaba la lucha titánica, casi perdida, que 
merecía un «buen ejemplo» del triunfo de los caballeros de la corona; es decir, 
violencia al tope para exaltar al héroe mientras que demostraba su lealtad ante 
sus señores (y la espera de una buena fama y encomiendas). Así también puede 
entenderse al pobre Francisco Cortés y su anhelo por ir lo más lejos posible del n
uevo horizonte español, esa frontera donde la ficción aún podía fundirse con la 
realidad; pese a su intento, olvidó que la puesta al límite implica una relación 
de poder, la cual siempre sería opacada por su pariente más sobresaliente, el 
mismo Hernán Cortés, teniendo una muerte trágica, una muerte buscada por un 
caballero sediento de fama.

La asimilación americana fue a través de cada uno de los españoles, porque de
esas tierras lo único que sabían era lo que les contaban. Fue el contacto de
una cultura por medio de la piel, el hierro, la técnica, la mirada y esa palabra
difusa del caballero que engaña y que no ve del americano mas que un intermedio
entre él y las riquezas de América. Cuando de otra cultura solo se tiene al otro
para comprenderla, cualquier objeto, cualquier cháchara, cualquier conversación
es deseada para poder digerir esa realidad que se tienta desmoronada. Que se
vaya el oro, que se haga la fiesta, que los recursos que se tienen y pueden
volver a obtenerse se inviertan en cualquier partícula de aquello que no nace
en esta tierra: espejos y conversaciones. La técnica fue una parte importante
entre la digestión en este límite, cuando Cortés mandaba a dar cañonazos,
causaba más pánico el estruendo y el hedor de la pólvora quemada que la 
capacidad destructiva del cañón. El caballo no se veía como un instrumento 
militar al modo en que los españoles lo daban por sentado, ni los bergantines 
como señales de amenaza militar. Fue la envergadura, el ruidio, el olor y la 
textura tan novedosos para los americanos, tan más radicalmente inédito como 
insólito fue el panorama de estas tierras para los españoles. Esta manipulación 
de las sensaciones por parte de seres tan semejantes a los americanos fue lo que 
en su límite se captó como el deshilachamiento del mito en las hebras que 
componían las venas de aquellos entes. No eran totalmente dioses, pocos así lo 
creyeron, pero tampoco eran del todo hombres porque esa técnica no formaba parte 
de este horizonte mundano. ¿Entonces? Asimilación con recelo hasta que con el 
tiempo los mismos españoles evidenciarán dos cosas: 1) son igualmente humanos y 
2) lo más aterrador no era su capacidad técnica, sino cómo su técnica estaba 
diseñada para dar muerte: armaduras, caballos, espadas, lanzas, cañones, 
bergantines y retórica, todo perfilado para manchar de sangre semejante porte.

Del espacio caballeresco y de la nueva técnica del hombre se siguió la
nivelación del tono. Los españoles se dieron cuenta que América no era una
tierra de riquezas que solo era necesario recoger sus frutos, sino un continente
que habría de trabajarse y planificarse según el modo de obtención de riquezas
que su horizonte ya conocía y con la «ayuda» de los nativos de estas tierras: no 
fue suerte, sino el trabajo intelectual y físico lo que abrió la puerta de oro a 
España y la desgracia de los americanos que fueron usados como fuerza laboral 
para este fin o exterminados por su poca voluntad de subsumirse. Los americanos 
en la sed material de los españoles y su extraña idea de un Dios de tres 
dimensiones (la humana, la paloma y el sin cuerpo) cayeron en cuenta que los 
europeos no se distanciaban mucho de ellos: no fue ingenuidad, sino un proceso
de asimilación de la encarnación del mito a la desmitificación. Aconteció un
fenómeno de «humanización»: verse a sí mismo en el otro.

Un encuentro fundamental fue entre los viejos americanos y los monjes
franciscanos. El fenómeno de humanización solo duró días. Entre las 
conversaciones se percibió un transfondo común completamente «humano» de
dudas y tentativas de respuesta respecto al significado, el sentido y la raíz
de cada una de estas realidades. Pero la distancia también fue garrafal. Los
españoles no lograban entender la importancia y el sentido que las celebraciones
tenían en Mesoamérica, incluida entre estas la práctica del sacrificio. A los
americanos les costaba abstraer la idea de un Dios que consistía de tres seres, 
siendo uno de estos «alguien» que carecía de todo cuerpo, así como les pareció 
absurdo la autoridad dada a una persona que decía que era suyo unas tierras que 
nunca había trabajado ni por lo menos visto. En este breve «encuentro» aconteció 
el «desencuentro»: la cruz o la guerra.

En no «encontrarse» fue la imposibilidad de percibir en el otro un
humano-humano; es decir, un hombre tal como en cada mundo se conocía como tal:
era de bárbaros el sacrificio, era lo locos o borrachos el creer en semejante
divinidad o en un tlatoani que se arropaba todo el mundo para sí. El proceso
de diferenciación por parte de los españoles fue desde un sentido 
ético-religioso, donde todos los americanos eran humanos, pero portadores del 
pecado original, por lo que era preciso el tutelaje por acuerdo mutuo, cuyo 
principal guía fue Bartolomé de las Casas. O la distinción fue de un modo 
naturalista: los indios carecían de razón natural, por lo que se justificaba la 
guerra en caso de no querer aceptar la cruz, por ellos y el futuro de los 
americanos, siendo Juan Ginés de Sepúlveda su mayor punto de relieve. De la 
Junta de Valladolid se desprendió la justificación necesaria para lo que ya se 
estaba llevando a cabo en América.

El proceso de diferenciación entre los americanos fue desconfianza ante la
palabra de los españoles, sentimiento de culpa por haber dado abrigo al
enemigo y una actitud de vencimiento por haber traicionado los fundamentos de
su mundo. Los conquistadores poco a poco mutaron en una plaga enviada por los
dioses a modo de castigo, no más rituales, no más sacrificios podrían salvar
al mundo que se derretía. Y cuando el centro de la realidad se fragmenta en
mil pedazos o cuando la realidad era tan pesada, lo más anhelado es aniquilarla
de modo contundente y reservar una migaja a modo de refugio. Quienes  ostentaban 
el poder no les quedó sino tratar de enmendar sus abusos del pasado, en poco 
tiempo, tan despojada de orgullo que fue motivo de recelo, en lugar de 
convencimiento. A esos americanos, a los autodenominados aztecas, la lucha y 
la muerte digna fueron sus opciones. Pobre Moctezuma, la vergüenza de América, 
y Cuauhtémoc, ese trágico *élen vital* que anuncia la retirada por lo alto de 
una era. Los bárbaros del norte, se fueron con el sol al morir la tarde, danza 
afligida con Huitzilopochtli y su universo de valores guerreros. Entre los 
dominados por ese «imperio», los españoles se percibieron como un mal menor, o 
al menos como esa maldad necesaria para salvaguardar lo poco que les quedaba. 
Las alianzas o las treguas era lo más viable cuando en el mundo en el que se 
vivía se estaba siempre a la sombra de una voluntad más fuerte y violenta como 
fue esa tribú chichimeca que fundó Tenochtitlan.

Diferenciación en sentido ético-religioso o naturalista, o como ocaso digno
o nuevo sometimiento, por desgracia no fue suficiente para el proceso de
aculturación de dos mundos. En esta tierra y con ese contraste de posturas
solo un mundo era posible: la confrontación ocurrió. Noches tristes, quema
de pueblos, suicidios colectivos y traiciones es como se traduce la parte más
obvia de este proceso de aculturación. Henán Cortés en la huida por la pérdida
de control ocasionada por sus huestes; una revancha que marcó el hito para
demostrar que Tenochtitlan no era invensible; la «pacificación» del Pánuco o
del occidente como «buen ejemplo» de la capacidad bélica española por negar la 
cruz; los amotinamientos de los americanos que en varias ocasiones estuvieron 
cerca de crear un punto de referencia sobre la debilidad de los españoles; unos 
americanos que prefirieron matarse, asesinar a sus hijos y clavarse cuchillos 
sobre el vientre para que ni ellos ni su estirpe tuvieran un destino reducido 
a ser animales de carga que comían restos de maíz, como lo describió Lebrón de 
Quiñones; un Tzintzuntzan que de manera tan hábil pudo mantener una relativa paz 
con Cristóbal de Olid, uno de los generales de Cortés, pero cuya tregua fue tan 
frágil como liviana se mostró la palabra de Nuño de Guzmán que quemó al «rey» y 
al «reino» de los purépechas.

Si bien este relato es más una trama construida que la sucesión precisa de
hechos históricos, lo que quiero poner de relieve es que la comprensión del
«decubrimiento», «invención», «encuentro», «desencuentro» y «choque» de América
es tanto un conjunto de hechos como su reconstrucción para tener un conocimiento
general de este momento específico de nuestra historia. Esta reestructuración
tan nuestra se comprende a través de estos fenómenos: 1) el desconocimiento y
los procesos de 2) asimilación a través del límite, 3) humanización, 4)
diferenciación y, por último, 5) confrontación. Es un factor fenoménico 
descrito desde una perspectiva general al hablar de americanos y españoles.
Pero quizá también sean aplicables, con sus respectivas modifiacciones o
ausencias, desde un punto de vista individual y no solo para la comprensión
de la conquista de América…

## La aculturación en la inteligencia artificial

---

Desconocimiento
Asimilación a través del límite de lo real (mito y ficción)
Humanización
Diferenciación
Confrontación

=> Aculturación

Más que el europeo haya dotado de «ser» a América, le
implantó un orden de las cosas en torno a algo tan desconocido y euroasiático
como lo es el concepto de «ser». 

un conjunto de hechos como su reconstrucción para tener un conocimiento
general de este momento específico de nuestra historia. Esta reestructuración
tan nuestra se comprende a través de estos fenómenos: 1) el desconocimiento y
los procesos de 2) asimilación a través del límite, 3) humanización, 4)
diferenciación y, por último, 5) confrontación.

Pero prefiero otra división cuando se trata del problema sobre si la IA 
«piensa», que a lo largo de este texto intentaré indicar su pertinencia:
EMULACIÓN o EXPLORACIÓN.
